summaryrefslogtreecommitdiffstats
path: root/kmahjongg/GameTimer.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmahjongg/GameTimer.cpp')
-rw-r--r--kmahjongg/GameTimer.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmahjongg/GameTimer.cpp b/kmahjongg/GameTimer.cpp
index d4fc4009..f3ce4f52 100644
--- a/kmahjongg/GameTimer.cpp
+++ b/kmahjongg/GameTimer.cpp
@@ -8,11 +8,11 @@
//
// Constructs a GameTimer widget with a tqparent and a name.
//
-GameTimer::GameTimer( TQWidget *tqparent, const char *name )
- : TQLCDNumber( tqparent, name )
+GameTimer::GameTimer( TQWidget *parent, const char *name )
+ : TQLCDNumber( parent, name )
{
showingColon = false;
setNumDigits(7);
@@ -8,11 +8,11 @@
//
-// Constructs a GameTimer widget with a tqparent and a name.
+// Constructs a GameTimer widget with a parent and a name.
//